Package 'qiverse.data'

Title: Quality Improvement Package Data
Description: Sample data used in the qiverse packages.
Authors: Healthcare Quality Intelligence Unit (Western Australia Health) [aut, cre]
Maintainer: Healthcare Quality Intelligence Unit (Western Australia Health) <[email protected]>
License: GPL (>= 3) + file LICENSE
Version: 0.0.1.0
Built: 2026-05-28 02:40:20 UTC
Source: https://github.com/AUS-DOH-Safety-and-Quality/qiverse

Help Index


Example Funnel Data

Description

Example funnel plot data used as an input to the data cleaning step for the Multiple Indicator Sigma Chart.

Usage

example_funnel_data

Format

example_funnel_data

A data frame with 66 rows and 4 columns:

indicator

The indicator name that matches the indicator column from the indicator_data

group

The group (hospital) for which this row contains data from

numerator

The numerator value for the indicator and hospital combination

denominator

The denominator value for the indicator and hospital combination


Example Indicator Data

Description

Example set of indicators used as an input to the data cleaning step for the Multiple Indicator Sigma Chart.

Usage

example_indicator_data

Format

example_indicator_data

A data frame with 6 rows and 5 columns:

indicator_theme

The theme (group) that the indicator belongs to

indicator

The name of the indicator itself

multiplier

The multiplier applied to the indicator

data_type

The type of funnel plot used in the FunnelPlotR package

betteris

The direction of favourability for the indicator. I.e. set to "Lower" when the indicator is improving as it decreases, and set to "Higher" when the indicator is improving as it increases.


Example SPC Data

Description

Example set of indicators used as an input SPC Funnel Matrix Prep Data Step

Usage

example_spc_data

Format

example_spc_data

A data frame with 1584 rows and 10 columns:

indicator

The unique identifier for the indicator itself

group

The unique identifier for the group/establishment

period_end

The end date of each SPC period

period_start

The start date of each SPC period

numerator

The numerator value for the indicator, group and period combination

denominator

The denominator value for the indicator, group and period combination

multiplier

The multiplier applied to the indicator

better_is

The direction of favourability for the indicator. I.e. set to "Lower" when the indicator is improving as it decreases, and set to "Higher" when the indicator is improving as it increases.

spc_chart_type

The type of SPC used in the qiverse.data.qipatterns package

funnel_chart_type

The type of funnel plot used in the FunnelPlotR package