| Title: | Quality Improvement Package Data |
|---|---|
| Description: | Sample data used in the qiverse packages. |
| Authors: | Healthcare Quality Intelligence Unit (Western Australia Health) [aut, cre] |
| Maintainer: | Healthcare Quality Intelligence Unit (Western Australia Health) <[email protected]> |
| License: | GPL (>= 3) + file LICENSE |
| Version: | 0.0.1.0 |
| Built: | 2026-05-28 02:40:20 UTC |
| Source: | https://github.com/AUS-DOH-Safety-and-Quality/qiverse |
Example funnel plot data used as an input to the data cleaning step for the Multiple Indicator Sigma Chart.
example_funnel_dataexample_funnel_data
example_funnel_dataA data frame with 66 rows and 4 columns:
The indicator name that matches the indicator column from the indicator_data
The group (hospital) for which this row contains data from
The numerator value for the indicator and hospital combination
The denominator value for the indicator and hospital combination
Example set of indicators used as an input to the data cleaning step for the Multiple Indicator Sigma Chart.
example_indicator_dataexample_indicator_data
example_indicator_dataA data frame with 6 rows and 5 columns:
The theme (group) that the indicator belongs to
The name of the indicator itself
The multiplier applied to the indicator
The type of funnel plot used in the FunnelPlotR package
The direction of favourability for the indicator. I.e. set to "Lower" when the indicator is improving as it decreases, and set to "Higher" when the indicator is improving as it increases.
Example set of indicators used as an input SPC Funnel Matrix Prep Data Step
example_spc_dataexample_spc_data
example_spc_dataA data frame with 1584 rows and 10 columns:
The unique identifier for the indicator itself
The unique identifier for the group/establishment
The end date of each SPC period
The start date of each SPC period
The numerator value for the indicator, group and period combination
The denominator value for the indicator, group and period combination
The multiplier applied to the indicator
The direction of favourability for the indicator. I.e. set to "Lower" when the indicator is improving as it decreases, and set to "Higher" when the indicator is improving as it increases.
The type of SPC used in the qiverse.data.qipatterns package
The type of funnel plot used in the FunnelPlotR package